==> idealyzer-1.0.9.tar.gz: idealyzer/src/Service/SiteScannerResultService.php <==
<?php

namespace Drupal\idealyzer\Service;

use Drupal\idealyzer\Entity\SiteScannerResult;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Database\Database;

/**
 * Class SiteScannerResultService.
 */
class SiteScannerResultService {

  /**
   * The entity type manager.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * Constructs a new SiteScannerResultService.
   *
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
   *   The entity type manager.
   */
  public function __construct(EntityTypeManagerInterface $entity_type_manager) {
    $this->entityTypeManager = $entity_type_manager;
  }

  /**
   * Create or update a SiteScannerResult entity from the given data.
   *
   * @param array $data
   *   The data to create or update the entity from.
   *
   * @return \Drupal\idealyzer\Entity\SiteScannerResult
   *   The created or updated SiteScannerResult entity.
   */
  public function createOrUpdateEntityFromData(array $data) {
    $storage = $this->entityTypeManager->getStorage('site_scanner_result');
    $existing_entities = $storage->loadByProperties([
      'final_url' => $data['final_url'],
      'dns_scan_status' => $data['dns_scan_status'],
      'not_found_scan_status' => $data['not_found_scan_status'],
      'security_scan_status' => $data['security_scan_status'],
    ]);
    if ($existing_entity = reset($existing_entities)) {
      // Update the existing entity with new data.
      foreach ($data as $key => $value) {
        if ($existing_entity->hasField($key)) {
          $existing_entity->set($key, $value);
          //\Drupal::logger('idealyzer')->info('saved over existing @key', ['@key' => $key]);
        }
      }

      $existing_entity->save();
      //\Drupal::logger('idealyzer')->info('saved over existing @data', ['@data' => $existing_entity]);

      return $existing_entity;
    } else {
      // Create a new entity.
      $entity = SiteScannerResult::create($data);
      $entity->save();
      \Drupal::logger('idealyzer')->info('created new @data', ['@data' => $entity]);
      return $entity;
    }
  }

  /**
   * Save multiple SiteScannerResult entities from the API response.
   *
   * @param array $response
   *   The API response data.
   */
  public function saveResults(array $response) {
    foreach ($response['items'] as $item) {
      if (isset($item['final_url']) && !empty($item['final_url'])) {
        $scan_date = (new \DateTime($item['scan_date']))->format('Y-m-d H:i:s');

        $data = [
          'scan_date' => $scan_date,
          'not_found_scan_status' => $item['not_found_scan_status'],
          'primary_scan_status' => $item['primary_scan_status'],
          'robots_txt_scan_status' => $item['robots_txt_scan_status'],
          'sitemap_xml_scan_status' => $item['sitemap_xml_scan_status'],
          'dns_scan_status' => $item['dns_scan_status'],
          'target_url_domain' => $item['target_url_domain'],
          'final_url' => substr($item['final_url'], 0, 255),
          'final_url_live' => $item['final_url_live'],
          'final_url_domain' => $item['final_url_domain'],
          'final_url_media_type' => $item['final_url_media_type'],
          'final_url_same_domain' => $item['final_url_same_domain'],
          'final_url_status_code' => $item['final_url_status_code'],
          'final_url_same_website' => $item['final_url_same_website'],
          'target_url_404_test' => $item['target_url_404_test'],
          'target_url_redirects' => $item['target_url_redirects'],
          'uswds_usa_classes' => $item['uswds_usa_classes'],
          'uswds_string' => $item['uswds_string'],
          'uswds_inpage_css' => $item['uswds_inpage_css'],
          'uswds_favicon' => $item['uswds_favicon'],
          'uswds_string_in_css' => $item['uswds_string_in_css'],
          'uswds_favicon_in_css' => $item['uswds_favicon_in_css'],
          'uswds_publicsans_font' => $item['uswds_publicsans_font'],
          'uswds_semantic_version' => $item['uswds_semantic_version'],
          'uswds_version' => $item['uswds_version'],
          'uswds_count' => $item['uswds_count'],
          'dap' => $item['dap'],
          'dap_parameters' => $item['dap_parameters'],
          'og_title' => $item['og_title'],
          'og_description' => $item['og_description'],
          'og_article_published' => $item['og_article_published'],
          'og_article_modified' => $item['og_article_modified'],
          'main_element_present' => $item['main_element_present'],
          'robots_txt_final_url' => substr($item['robots_txt_final_url'], 0, 255),
          'robots_txt_final_url_status_code' => $item['robots_txt_final_url_status_code'],
          'robots_txt_final_url_live' => $item['robots_txt_final_url_live'],
          'robots_txt_detected' => $item['robots_txt_detected'],
          'robots_txt_final_url_media_type' => $item['robots_txt_final_url_media_type'],
          'robots_txt_target_url_redirects' => $item['robots_txt_target_url_redirects'],
          'robots_txt_final_url_filesize' => $item['robots_txt_final_url_filesize'],
          'robots_txt_crawl_delay' => $item['robots_txt_crawl_delay'],
          'robots_txt_sitemap_locations' => $item['robots_txt_sitemap_locations'],
          'sitemap_xml_detected' => $item['sitemap_xml_detected'],
          'sitemap_xml_final_url_status_code' => $item['sitemap_xml_final_url_status_code'],
          'sitemap_xml_final_url' => substr($item['sitemap_xml_final_url'], 0, 255),
          'sitemap_xml_final_url_live' => $item['sitemap_xml_final_url_live'],
          'sitemap_xml_target_url_redirects' => $item['sitemap_xml_target_url_redirects'],
          'sitemap_xml_final_url_filesize' => $item['sitemap_xml_final_url_filesize'],
          'sitemap_xml_final_url_media_type' => $item['sitemap_xml_final_url_media_type'],
          'sitemap_xml_count' => $item['sitemap_xml_count'],
          'sitemap_xml_pdf_count' => $item['sitemap_xml_pdf_count'],
          'third_party_service_domains' => $item['third_party_service_domains'],
          'third_party_service_count' => $item['third_party_service_count'],
          'cookie_domains' => $item['cookie_domains'],
          'ipv6' => $item['ipv6'],
          'login' => $item['login'],
          'hostname' => $item['hostname'],
          'final_url_website' => $item['final_url_website'],
          'final_url_top_level_domain' => $item['final_url_top_level_domain'],
          'canonical_link' => $item['canonical_link'],
          'cms' => $item['cms'],
          'required_links_url' => $item['required_links_url'],
          'required_links_text' => $item['required_links_text'],
          'login_provider' => $item['login_provider'],
          'site_search' => $item['site_search'],
          'search_dot_gov' => $item['search_dot_gov'],
          'accessibility_scan_status' => $item['accessibility_scan_status'],
          'viewport_meta_tag' => $item['viewport_meta_tag'],
          'title' => substr($item['title'], 0, 255),
          'description' => $item['description'],
          'performance_scan_status' => $item['performance_scan_status'],
          'largest_contentful_paint' => $item['largest_contentful_paint'],
          'cumulative_layout_shift' => $item['cumulative_layout_shift'],
          'keywords' => $item['keywords'],
          'og_image' => $item['og_image'],
          'og_type' => $item['og_type'],
          'og_url' => $item['og_url'],
          'language' => $item['language'],
          'language_link' => $item['language_link'],
          'security_scan_status' => $item['security_scan_status'],
          'https_enforced' => $item['https_enforced'],
          'hsts' => $item['hsts'],
          'uswds_usa_class_list' => $item['uswds_usa_class_list'],
          'target_url' => $item['target_url'],
          'target_url_top_level_domain' => $item['target_url_top_level_domain'],
          'target_url_branch' => $item['target_url_branch'],
          'target_url_agency_owner' => $item['target_url_agency_owner'],
          'target_url_bureau_owner' => $item['target_url_bureau_owner'],
          'source_list' => $item['source_list'],
          'public' => $item['public'],
          'scan_data' => json_encode($item),
        ];
        // Create or update the entity.
        $this->createOrUpdateEntityFromData($data);
      }
      else {
        //\Drupal::logger('idealyzer')->info('Aborted scan due to DNS issue: @data', ['@data' => $item['final_url_domain']]);
      }
    }
  }
}

==> idealyzer-1.0.12.tar.gz: idealyzer/src/Service/SiteScannerResultService.php <==
<?php

namespace Drupal\idealyzer\Service;

use Drupal\idealyzer\Entity\SiteScannerResult;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Database\Database;

/**
 * Class SiteScannerResultService.
 */
class SiteScannerResultService {

  /**
   * The entity type manager.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * Constructs a new SiteScannerResultService.
   *
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
   *   The entity type manager.
   */
  public function __construct(EntityTypeManagerInterface $entity_type_manager) {
    $this->entityTypeManager = $entity_type_manager;
  }

  /**
   * Create or update a SiteScannerResult entity from the given data.
   *
   * @param array $data
   *   The data to create or update the entity from.
   *
   * @return \Drupal\idealyzer\Entity\SiteScannerResult
   *   The created or updated SiteScannerResult entity.
   */
  public function createOrUpdateEntityFromData(array $data) {
    $storage = $this->entityTypeManager->getStorage('site_scanner_result');
    $existing_entities = $storage->loadByProperties([
      'final_url' => $data['final_url'],
      'dns_scan_status' => $data['dns_scan_status'],
      'not_found_scan_status' => $data['not_found_scan_status'],
      'security_scan_status' => $data['security_scan_status'],
    ]);
    if ($existing_entity = reset($existing_entities)) {
      // Update the existing entity with new data.
      foreach ($data as $key => $value) {
        if ($existing_entity->hasField($key)) {
          $existing_entity->set($key, $value);
          //\Drupal::logger('idealyzer')->info('saved over existing @key', ['@key' => $key]);
        }
      }

      $existing_entity->save();
      //\Drupal::logger('idealyzer')->info('saved over existing @data', ['@data' => $existing_entity]);

      return $existing_entity;
    } else {
      // Create a new entity.
      $entity = SiteScannerResult::create($data);
      $entity->save();
      //\Drupal::logger('idealyzer')->info('created new @data', ['@data' => $entity]);
      return $entity;
    }
  }

  /**
   * Save multiple SiteScannerResult entities from the API response.
   *
   * @param array $response
   *   The API response data.
   */
  public function saveResults(array $response) {
    foreach ($response['items'] as $item) {
      if (isset($item['final_url']) && !empty($item['final_url'])) {
        $scan_date = (new \DateTime($item['scan_date']))->format('Y-m-d H:i:s');

        $data = [
          'scan_date' => $scan_date,
          'not_found_scan_status' => $item['not_found_scan_status'],
          'primary_scan_status' => $item['primary_scan_status'],
          'robots_txt_scan_status' => $item['robots_txt_scan_status'],
          'sitemap_xml_scan_status' => $item['sitemap_xml_scan_status'],
          'dns_scan_status' => $item['dns_scan_status'],
          'target_url_domain' => $item['target_url_domain'],
          'final_url' => substr($item['final_url'], 0, 255),
          'final_url_live' => $item['final_url_live'],
          'final_url_domain' => $item['final_url_domain'],
          'final_url_media_type' => $item['final_url_media_type'],
          'final_url_same_domain' => $item['final_url_same_domain'],
          'final_url_status_code' => $item['final_url_status_code'],
          'final_url_same_website' => $item['final_url_same_website'],
          'target_url_404_test' => $item['target_url_404_test'],
          'target_url_redirects' => $item['target_url_redirects'],
          'uswds_usa_classes' => $item['uswds_usa_classes'],
          'uswds_string' => $item['uswds_string'],
          'uswds_inpage_css' => $item['uswds_inpage_css'],
          'uswds_favicon' => $item['uswds_favicon'],
          'uswds_string_in_css' => $item['uswds_string_in_css'],
          'uswds_favicon_in_css' => $item['uswds_favicon_in_css'],
          'uswds_publicsans_font' => $item['uswds_publicsans_font'],
          'uswds_semantic_version' => $item['uswds_semantic_version'],
          'uswds_version' => $item['uswds_version'],
          'uswds_count' => $item['uswds_count'],
          'dap' => $item['dap'],
          'dap_parameters' => $item['dap_parameters'],
          'og_title' => $item['og_title'],
          'og_description' => $item['og_description'],
          'og_article_published' => $item['og_article_published'],
          'og_article_modified' => $item['og_article_modified'],
          'main_element_present' => $item['main_element_present'],
          'robots_txt_final_url' => substr($item['robots_txt_final_url'], 0, 255),
          'robots_txt_final_url_status_code' => $item['robots_txt_final_url_status_code'],
          'robots_txt_final_url_live' => $item['robots_txt_final_url_live'],
          'robots_txt_detected' => $item['robots_txt_detected'],
          'robots_txt_final_url_media_type' => $item['robots_txt_final_url_media_type'],
          'robots_txt_target_url_redirects' => $item['robots_txt_target_url_redirects'],
          'robots_txt_final_url_filesize' => $item['robots_txt_final_url_filesize'],
          'robots_txt_crawl_delay' => $item['robots_txt_crawl_delay'],
          'robots_txt_sitemap_locations' => $item['robots_txt_sitemap_locations'],
          'sitemap_xml_detected' => $item['sitemap_xml_detected'],
          'sitemap_xml_final_url_status_code' => $item['sitemap_xml_final_url_status_code'],
          'sitemap_xml_final_url' => substr($item['sitemap_xml_final_url'], 0, 255),
          'sitemap_xml_final_url_live' => $item['sitemap_xml_final_url_live'],
          'sitemap_xml_target_url_redirects' => $item['sitemap_xml_target_url_redirects'],
          'sitemap_xml_final_url_filesize' => $item['sitemap_xml_final_url_filesize'],
          'sitemap_xml_final_url_media_type' => $item['sitemap_xml_final_url_media_type'],
          'sitemap_xml_count' => $item['sitemap_xml_count'],
          'sitemap_xml_pdf_count' => $item['sitemap_xml_pdf_count'],
          'third_party_service_domains' => $item['third_party_service_domains'],
          'third_party_service_count' => $item['third_party_service_count'],
          'cookie_domains' => $item['cookie_domains'],
          'ipv6' => $item['ipv6'],
          'login' => $item['login'],
          'hostname' => $item['hostname'],
          'final_url_website' => $item['final_url_website'],
          'final_url_top_level_domain' => $item['final_url_top_level_domain'],
          'canonical_link' => $item['canonical_link'],
          'cms' => $item['cms'],
          'required_links_url' => $item['required_links_url'],
          'required_links_text' => $item['required_links_text'],
          'login_provider' => $item['login_provider'],
          'site_search' => $item['site_search'],
          'search_dot_gov' => $item['search_dot_gov'],
          'accessibility_scan_status' => $item['accessibility_scan_status'],
          'viewport_meta_tag' => $item['viewport_meta_tag'],
          'title' => substr($item['title'], 0, 255),
          'description' => $item['description'],
          'performance_scan_status' => $item['performance_scan_status'],
          'largest_contentful_paint' => $item['largest_contentful_paint'],
          'cumulative_layout_shift' => $item['cumulative_layout_shift'],
          'keywords' => $item['keywords'],
          'og_image' => $item['og_image'],
          'og_type' => $item['og_type'],
          'og_url' => $item['og_url'],
          'language' => $item['language'],
          'language_link' => $item['language_link'],
          'security_scan_status' => $item['security_scan_status'],
          'https_enforced' => $item['https_enforced'],
          'hsts' => $item['hsts'],
          'uswds_usa_class_list' => $item['uswds_usa_class_list'],
          'target_url' => $item['target_url'],
          'target_url_top_level_domain' => $item['target_url_top_level_domain'],
          'target_url_branch' => $item['target_url_branch'],
          'target_url_agency_owner' => $item['target_url_agency_owner'],
          'target_url_bureau_owner' => $item['target_url_bureau_owner'],
          'source_list' => $item['source_list'],
          'public' => $item['public'],
          'scan_data' => json_encode($item),
        ];
        // Create or update the entity.
        $this->createOrUpdateEntityFromData($data);
      }
      else {
        //\Drupal::logger('idealyzer')->info('Aborted scan due to DNS issue: @data', ['@data' => $item['final_url_domain']]);
      }
    }
  }
}
